#pragma once
/*++

Copyright (c) Pico Systems Co., Ltd.

Module Name: bvcm.h

Abstract:

	Support Library for BVCM-MIF-02
	BVCM Dynamic Link library definitions

Revision History:

	19/Jun/2017   Created by Makoto Ito

--*/
#pragma once  

#include "windows.h"


// The following ifdef block is the standard way of creating macros
// which make exporting from a DLL simpler.

#ifdef BVCM_DLL_EXPORTS
#define BVCM_API __declspec(dllexport)   
#else  
#define BVCM_API __declspec(dllimport)   
#endif  

// Type Definition

typedef HANDLE	BVCM_HANDLE;
typedef ULONG	BVCM_STATUS;

// Device status

enum
{
	BVCM_OK,
	BVCM_INVALID_HANDLE,
	BVCM_IO_ERROR,
	BVCM_INVALID_PARAMETER,
	BVCM_NO_RESPONSE,
	BVCM_OTHER_ERROR,
	BVCM_ACK1,
	BVCM_ACK2,
	BVCM_ACK3,
	BVCM_ACK4,
	BVCM_NAK,
	BVCM_BUSY
};

// Device Type

#define	BVCM_BILL 0x58
#define	BVCM_COIN 0x60
#define	BVCM_CARD 0xE0

#define STX			0x02
#define ETX			0x03
#define CR			0x0D
#define ESC			0x7D
#define ESC_STX		0xE2
#define ESC_ETX		0xE3
#define ESC_ESC		0x5D
#define HOST_ADRES	0x00
#define BVCM_ADRS	0x20

// Functions to Export

BVCM_API
BVCM_STATUS WINAPI BVCM_ScanInterface
(
	LPSTR psComPort
);

BVCM_API
BVCM_STATUS WINAPI BVCM_OpenInterface
(
	LPSTR psComPort,
	BVCM_HANDLE* bvcmHandle
);

BVCM_API
BVCM_STATUS WINAPI BVCM_CloseInterface
(
	BVCM_HANDLE bvcmHandle
);

BVCM_API
BVCM_STATUS WINAPI BVCM_Standby
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget
);

BVCM_API
BVCM_STATUS WINAPI BVCM_GetAllData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	unsigned char* pcBuffer,
	unsigned int uiBufferSize
);

BVCM_API
BVCM_STATUS WINAPI BVCM_GetData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	unsigned char* pcBuffer,
	unsigned int uiBufferSize
);

BVCM_API
BVCM_STATUS WINAPI BVCM_PutData
(
	BVCM_HANDLE bvcmHandle,
	unsigned int uiTarget,
	unsigned char* pcBuffer
);

BVCM_API
BVCM_STATUS WINAPI BVCM_LineReset
(
	BVCM_HANDLE bvcmHandle
);

BVCM_API
BVCM_STATUS WINAPI BVCM_GetVersion
(
	BVCM_HANDLE bvcmHandle,
	unsigned char* pcBuffer,
	unsigned int uiBufferSize
);
